==> xld-azure-plugin-7.0.0.jar: xld/azure/network_interface/create-or-update.py <==
from azure.mgmt.network.models import NetworkInterface, NetworkInterfaceIPConfiguration
from azure.mgmt.network.models import NetworkInterfaceDnsSettings
from xld.azure import string_or_none, object_or_none, boolean_or_none

from xld.azure.connector import AzureConnector

connector = AzureConnector(deployed.container)

network_client = connector.network_client()

network_interface_dns_settings = None
if deployed.dnsSettingsEnable:
    print "Creating NetworkInterface DNS settings ..."
    network_interface_dns_settings = NetworkInterfaceDnsSettings(
        dns_servers=deployed.dnsServers,
        applied_dns_servers=deployed.appliedDnsServers,
        internal_dns_name_label=deployed.internalDnsNameLabel,
        internal_fqdn=deployed.internalFqdn,
        internal_domain_name_suffix=deployed.internalDomainNameSuffix
    )

print "Creating NetworkInterface IP configurations ..."
print deployed.ipConfigurations

network_interface_ip_configurations = []

for configuration in deployed.ipConfigurations:

    print "Add NetworkInterface IP configuration"

    network_client2 = connector.network_client()  # temporary workaround
    network_interface_subnet = network_client2.subnets.get(
        deployed.resourceGroupName,
        configuration.virtualNetworkName,
        configuration.subnet)

    # print network_interface_subnet
    network_interface_public_ip_address = None
    if configuration.publicIpAddress:
        network_client3 = connector.network_client()  # temporary workaround
        network_interface_public_ip_address = network_client3.public_ip_addresses.get(
            resource_group_name=deployed.resourceGroupName,
            public_ip_address_name=configuration.publicIpAddress
        )
        print "Resolved public ip address to {0}".format(network_interface_public_ip_address)

    logger.info("NetworkInterface IP configurations: {0}".format(configuration))

    network_interface_ip_configurations.append(
        NetworkInterfaceIPConfiguration(
            private_ip_address=string_or_none(configuration.privateIpAddress),
            private_ip_allocation_method=string_or_none(configuration.privateIpAllocationMethod),
            private_ip_address_version=string_or_none(configuration.privateIpAddressVersion),
            subnet=object_or_none(network_interface_subnet),
            primary=string_or_none(configuration.primary),
            public_ip_address=object_or_none(network_interface_public_ip_address),
            name=configuration.networkInterfaceIPConfigurationName
        )
    )

current_sg = None
if deployed.networkSecurityGroupName:
    tmp_network_client = connector.network_client()
    print "Looking up network security group '{0}'".format(deployed.networkSecurityGroupName)
    current_sg = tmp_network_client.network_security_groups.get(
        resource_group_name=deployed.resourceGroupName,
        network_security_group_name=deployed.networkSecurityGroupName
    )

print "Preparing NetworkInterface parameters ..."
network_interface_parameters = NetworkInterface(
    location=deployed.location,
    tags=deployed.networkInterfaceTags,
    network_security_group=current_sg,
    ip_configurations=object_or_none(network_interface_ip_configurations),
    dns_settings=object_or_none(network_interface_dns_settings),
    mac_address=string_or_none(deployed.macAddress),
    primary=boolean_or_none(deployed.primary),
    enable_ip_forwarding=boolean_or_none(deployed.enableIpForwarding)
)
logger.info("NetworkInterface parameters: {0}".format(network_interface_parameters))

print "Creating NetworkInterface ..."
result_create_op = network_client.network_interfaces.create_or_update(
    resource_group_name=deployed.resourceGroupName,
    network_interface_name=deployed.networkInterfaceName,
    parameters=network_interface_parameters,
    raw=True
)

logger.info("Result: {0}".format(result_create_op))

==> xld-azure-plugin-7.2.0.jar: xld/azure/network_interface/create-or-update.py <==
from azure.mgmt.network.models import NetworkInterface, NetworkInterfaceIPConfiguration
from azure.mgmt.network.models import NetworkInterfaceDnsSettings
from xld.azure import string_or_none, object_or_none, boolean_or_none

from xld.azure.connector import AzureConnector

rg = deployed.container
cloud = rg.container
connector = AzureConnector(cloud)

network_client = connector.network_client()

network_interface_dns_settings = None
if deployed.dnsSettingsEnable:
    print "Creating NetworkInterface DNS settings ..."
    network_interface_dns_settings = NetworkInterfaceDnsSettings(
        dns_servers=deployed.dnsServers,
        applied_dns_servers=deployed.appliedDnsServers,
        internal_dns_name_label=deployed.internalDnsNameLabel,
        internal_fqdn=deployed.internalFqdn,
        internal_domain_name_suffix=deployed.internalDomainNameSuffix
    )

print "Creating NetworkInterface IP configurations ..."
print deployed.ipConfigurations

network_interface_ip_configurations = []

for configuration in deployed.ipConfigurations:

    print "Add NetworkInterface IP configuration"

    network_client2 = connector.network_client()  # temporary workaround
    network_interface_subnet = network_client2.subnets.get(
        rg.resourceGroupName,
        configuration.virtualNetworkName,
        configuration.subnet)

    # print network_interface_subnet
    network_interface_public_ip_address = None
    if configuration.publicIpAddress:
        network_client3 = connector.network_client()  # temporary workaround
        network_interface_public_ip_address = network_client3.public_ip_addresses.get(
            resource_group_name=rg.resourceGroupName,
            public_ip_address_name=configuration.publicIpAddress
        )
        print "Resolved public ip address to {0}".format(network_interface_public_ip_address)

    logger.info("NetworkInterface IP configurations: {0}".format(configuration))

    network_interface_ip_configurations.append(
        NetworkInterfaceIPConfiguration(
            private_ip_address=string_or_none(configuration.privateIpAddress),
            private_ip_allocation_method=string_or_none(configuration.privateIpAllocationMethod),
            private_ip_address_version=string_or_none(configuration.privateIpAddressVersion),
            subnet=object_or_none(network_interface_subnet),
            primary=string_or_none(configuration.primary),
            public_ip_address=object_or_none(network_interface_public_ip_address),
            name=configuration.networkInterfaceIPConfigurationName
        )
    )

current_sg = None
if deployed.networkSecurityGroupName:
    tmp_network_client = connector.network_client()
    print "Looking up network security group '{0}'".format(deployed.networkSecurityGroupName)
    current_sg = tmp_network_client.network_security_groups.get(
        resource_group_name=rg.resourceGroupName,
        network_security_group_name=deployed.networkSecurityGroupName
    )

print "Preparing NetworkInterface parameters ..."
network_interface_parameters = NetworkInterface(
    location=deployed.location,
    tags=deployed.networkInterfaceTags,
    network_security_group=current_sg,
    ip_configurations=object_or_none(network_interface_ip_configurations),
    dns_settings=object_or_none(network_interface_dns_settings),
    mac_address=string_or_none(deployed.macAddress),
    primary=boolean_or_none(deployed.primary),
    enable_ip_forwarding=boolean_or_none(deployed.enableIpForwarding)
)
logger.info("NetworkInterface parameters: {0}".format(network_interface_parameters))

print "Creating NetworkInterface ..."
result_create_op = network_client.network_interfaces.create_or_update(
    resource_group_name=rg.resourceGroupName,
    network_interface_name=deployed.networkInterfaceName,
    parameters=network_interface_parameters,
    raw=True
)

logger.info("Result: {0}".format(result_create_op))
